==> Decorative%20Food-1.20.1-1.0.7-sources.jar: org/dfood/block/PotionBlock.java <==
package org.dfood.block;

import org.dfood.block.entity.PotionBlockEntity;
import org.jetbrains.annotations.Nullable;

import java.util.List;
import java.util.Objects;
import net.minecraft.class_1309;
import net.minecraft.class_1799;
import net.minecraft.class_1802;
import net.minecraft.class_181;
import net.minecraft.class_1844;
import net.minecraft.class_1937;
import net.minecraft.class_2338;
import net.minecraft.class_2343;
import net.minecraft.class_2487;
import net.minecraft.class_2586;
import net.minecraft.class_2680;
import net.minecraft.class_8567;

public class PotionBlock extends FoodBlock implements class_2343 {
    public PotionBlock(class_2251 settings, int max_food) {
        super(settings, max_food);
    }

    @Override
    public @Nullable class_2586 method_10123(class_2338 pos, class_2680 state) {
        return new PotionBlockEntity(pos, state);
    }

    @Override
    public void method_9567(class_1937 world, class_2338 pos, class_2680 state, @Nullable class_1309 placer, class_1799 itemStack) {
        super.method_9567(world, pos, state, placer, itemStack);
        class_2586 blockEntity = world.method_8321(pos);
        if (blockEntity instanceof PotionBlockEntity potionBlockEntity) {
            class_2487 stackNbt = itemStack.method_7969();
            if (stackNbt != null) {
                potionBlockEntity.readCustomDataFromItem(stackNbt);
            }
        }
    }

    @Override
    public boolean isSame(class_1799 stack, class_2586 blockEntity) {
        if (blockEntity instanceof PotionBlockEntity potionBlockEntity && super.isSame(stack, blockEntity)) {
            class_2487 potionStackNbt = potionBlockEntity.getPotionStack().method_7969();
            class_2487 stackNbt = stack.method_7969();
            if (stackNbt != null && potionStackNbt != null && stackNbt.method_10545("Potion") && potionStackNbt.method_10545("Potion")) {
                return Objects.equals(potionStackNbt.method_10558("Potion"), stackNbt.method_10558("Potion"));
            }
        }
        return false;
    }

    @Override
    public class_1799 createStack(int count, @Nullable class_2586 blockEntity) {
        class_1799 stack = new class_1799(class_1802.field_8574, count);
        if (blockEntity instanceof PotionBlockEntity potionBlockEntity) {
            return class_1844.method_8061(stack, potionBlockEntity.getPotion());
        }
        return stack;
    }

    @Override
    public List<class_1799> method_9560(class_2680 state, class_8567.class_8568 builder) {
        class_2586 blockEntity = builder.method_51876(class_181.field_1228);

        if (blockEntity instanceof PotionBlockEntity potionBlockEntity) {
            int count = state.method_11654(NUMBER_OF_FOOD);
            class_1799 baseStack = potionBlockEntity.getPotionStack();
            List<class_1799> drops = new java.util.ArrayList<>();
            for (int i = 0; i < count; i++) {
                drops.add(baseStack.method_7972());
            }
            return drops;
        }

        // 没有方块实体时，返回空列表
        return List.of();
    }
}

==> Decorative%20Food-1.21.1-1.0.6-sources.jar: org/dfood/block/PotionBlock.java <==
package org.dfood.block;

import org.dfood.block.entity.PotionBlockEntity;
import org.jetbrains.annotations.Nullable;

import java.util.List;
import java.util.Objects;
import net.minecraft.class_1309;
import net.minecraft.class_1799;
import net.minecraft.class_181;
import net.minecraft.class_1844;
import net.minecraft.class_1937;
import net.minecraft.class_2338;
import net.minecraft.class_2343;
import net.minecraft.class_2586;
import net.minecraft.class_2680;
import net.minecraft.class_8567;
import net.minecraft.class_9334;

public class PotionBlock extends FoodBlock implements class_2343 {
    public PotionBlock(class_2251 settings, int max_food) {
        super(settings, max_food);
    }

    @Override
    public @Nullable class_2586 method_10123(class_2338 pos, class_2680 state) {
        return new PotionBlockEntity(pos, state);
    }

    @Override
    public void method_9567(class_1937 world, class_2338 pos, class_2680 state, @Nullable class_1309 placer, class_1799 itemStack) {
        super.method_9567(world, pos, state, placer, itemStack);
        class_2586 blockEntity = world.method_8321(pos);
        if (blockEntity instanceof PotionBlockEntity potionBlockEntity) {
            class_1844 potionContents = itemStack.method_57824(class_9334.field_49651);
            if (potionContents != null) {
                potionBlockEntity.readCustomDataFromItem(potionContents);
            }
        }
    }

    @Override
    public boolean isSame(class_1799 stack, class_2586 blockEntity) {
        if (blockEntity instanceof PotionBlockEntity potionBlockEntity && super.isSame(stack, blockEntity)) {
            class_1844 potion = potionBlockEntity.getPotionStack().method_57824(class_9334.field_49651);
            class_1844 stackComponent = stack.method_57824(class_9334.field_49651);
            if (stackComponent != null && potion != null) {
                return Objects.equals(potion, stackComponent);
            }
        }
        return false;
    }

    @Override
    public class_1799 createStack(int count, @Nullable class_2586 blockEntity) {
        class_1799 stack = new class_1799(this.method_8389(), count);
        if (blockEntity instanceof PotionBlockEntity potionBlockEntity) {
            stack.method_57379(class_9334.field_49651, potionBlockEntity.getPotionContents());
            return stack;
        }
        return stack;
    }

    @Override
    public List<class_1799> method_9560(class_2680 state, class_8567.class_8568 builder) {
        class_2586 blockEntity = builder.method_51876(class_181.field_1228);

        if (blockEntity instanceof PotionBlockEntity potionBlockEntity) {
            int count = state.method_11654(NUMBER_OF_FOOD);
            class_1799 baseStack = potionBlockEntity.getPotionStack();
            List<class_1799> drops = new java.util.ArrayList<>();
            for (int i = 0; i < count; i++) {
                drops.add(baseStack.method_7972());
            }
            return drops;
        }

        // 没有方块实体时，返回空列表
        return List.of();
    }
}
